@@ -1,6 +1,8 @@
 # --
 # Kernel/Modules/AgentPreferences.pm - provides agent preferences
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# --
+# $Id: AgentPreferences.pm,v 1.50 2010/12/22 09:21:27 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,6 +14,9 @@ package Kernel::Modules::AgentPreferences;
 use strict;
 use warnings;
 
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.50 $) [1];
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -39,10 +44,6 @@ sub Run {
     # update preferences via AJAX
     # ------------------------------------------------------------ #
     if ( $Self->{Subaction} eq 'UpdateAJAX' ) {
-
-        # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
-
         my $Key   = $Self->{ParamObject}->GetParam( Param => 'Key' );
         my $Value = $Self->{ParamObject}->GetParam( Param => 'Value' );
 
@@ -107,13 +108,8 @@ sub Run {
         my @Params = $Object->Param( UserData => \%UserData );
         my %GetParam;
         for my $ParamItem (@Params) {
-            my @Array = $Self->{ParamObject}->GetArray(
-                Param => $ParamItem->{Name},
-                Raw => $ParamItem->{Raw} || 0,
-            );
-            if (defined $ParamItem->{Name}) {
-                $GetParam{ $ParamItem->{Name} } = \@Array;
-            }
+            my @Array = $Self->{ParamObject}->GetArray( Param => $ParamItem->{Name} );
+            $GetParam{ $ParamItem->{Name} } = \@Array;
         }
         my $Message  = '';
         my $Priority = '';
@@ -178,42 +174,23 @@ sub AgentPreferencesForm {
     );
 
     my @Groups = @{ $Self->{ConfigObject}->Get('PreferencesView') };
-
-    COLUMN:
     for my $Column (@Groups) {
-
-        next COLUMN if !$Column;
-
-        my %Data;
+        my %Data        = ();
         my %Preferences = %{ $Self->{ConfigObject}->Get('PreferencesGroups') };
-
-        GROUP:
-        for my $Group ( sort keys %Preferences ) {
-
-            next GROUP if !$Group;
-            next GROUP if !$Preferences{$Group};
-            next GROUP if ref $Preferences{$Group} ne 'HASH';
-            next GROUP if !$Preferences{$Group}->{Column};
-            next GROUP if $Preferences{$Group}->{Column} ne $Column;
-
-            # In case of a priority conflict, increase priority until a free slot is found.
-            if ( $Data{ $Preferences{$Group}->{Prio} } ) {
-
-                COUNT:
-                for ( 1 .. 151 ) {
-
-                    $Preferences{$Group}->{Prio}++;
-
-                    next COUNT if $Data{ $Preferences{$Group}->{Prio} };
-
-                    $Data{ $Preferences{$Group}->{Prio} } = $Group;
-                    last COUNT;
+        for my $Group ( keys %Preferences ) {
+            if ( $Preferences{$Group}->{Column} eq $Column ) {
+                if ( $Data{ $Preferences{$Group}->{Prio} } ) {
+                    for ( 1 .. 151 ) {
+                        $Preferences{$Group}->{Prio}++;
+                        if ( !$Data{ $Preferences{$Group}->{Prio} } ) {
+                            $Data{ $Preferences{$Group}->{Prio} } = $Group;
+                            last;
+                        }
+                    }
                 }
+                $Data{ $Preferences{$Group}->{Prio} } = $Group;
             }
-
-            $Data{ $Preferences{$Group}->{Prio} } = $Group;
         }
-
         $Self->{LayoutObject}->Block(
             Name => 'Column',
             Data => {
@@ -223,7 +200,7 @@ sub AgentPreferencesForm {
         );
 
         # sort
-        for my $Key ( sort keys %Data ) {
+        for my $Key ( keys %Data ) {
             $Data{ sprintf( "%07d", $Key ) } = $Data{$Key};
             delete $Data{$Key};
         }
