@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketSearch.pm - Utilities for tickets
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketSearch.pm,v 1.110 2010/11/15 11:40:22 mb Exp $
+# $Id: AgentTicketSearch.pm,v 1.118.2.7 2012/08/06 07:34:08 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -24,7 +24,7 @@ use Kernel::System::Type;
 use Kernel::System::CSV;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.110 $) [1];
+$VERSION = qw($Revision: 1.118.2.7 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -108,7 +108,7 @@ sub Run {
         );
         return $Self->{LayoutObject}->Attachment(
             Filename    => 'OpenSearchDescriptionTicketNumber.xml',
-            ContentType => 'text/xml',
+            ContentType => 'application/opensearchdescription+xml',
             Content     => $Output,
             Type        => 'inline',
         );
@@ -120,7 +120,7 @@ sub Run {
         );
         return $Self->{LayoutObject}->Attachment(
             Filename    => 'OpenSearchDescriptionFulltext.xml',
-            ContentType => 'text/xml',
+            ContentType => 'application/opensearchdescription+xml',
             Content     => $Output,
             Type        => 'inline',
         );
@@ -128,9 +128,10 @@ sub Run {
 
     # check request
     if ( $Self->{ParamObject}->GetParam( Param => 'SearchTemplate' ) && $Self->{Profile} ) {
+        my $Profile = $Self->{LayoutObject}->LinkEncode( $Self->{Profile} );
         return $Self->{LayoutObject}->Redirect(
             OP =>
-                "Action=AgentTicketSearch;Subaction=Search;TakeLastSearch=1;SaveProfile=1;Profile=$Self->{Profile}"
+                "Action=AgentTicketSearch;Subaction=Search;TakeLastSearch=1;SaveProfile=1;Profile=$Profile"
         );
     }
 
@@ -144,6 +145,11 @@ sub Run {
             Name      => $Self->{Profile},
             UserLogin => $Self->{UserLogin},
         );
+
+        # convert attributes
+        if ( $GetParam{ShownAttributes} && ref $GetParam{ShownAttributes} eq 'ARRAY' ) {
+            $GetParam{ShownAttributes} = join ';', @{ $GetParam{ShownAttributes} };
+        }
     }
 
     # get search string params (get submitted params)
@@ -152,7 +158,7 @@ sub Run {
             qw(TicketNumber Title From To Cc Subject Body CustomerID CustomerUserLogin StateType
             Agent ResultForm TimeSearchType ChangeTimeSearchType CloseTimeSearchType UseSubQueues
             ArticleTimeSearchType SearchInArchive
-            Fulltext
+            Fulltext ShownAttributes
             TicketFreeTime1
             TicketFreeTime1Start TicketFreeTime1StartDay TicketFreeTime1StartMonth
             TicketFreeTime1StartYear
@@ -340,17 +346,21 @@ sub Run {
                 UserLogin => $Self->{UserLogin},
             );
 
+            # convert attributes
+            if ( $GetParam{ShownAttributes} && ref $GetParam{ShownAttributes} eq '' ) {
+                $GetParam{ShownAttributes} = [ split /;/, $GetParam{ShownAttributes} ];
+            }
+
             # insert new profile params
             for my $Key ( keys %GetParam ) {
-                if ( $GetParam{$Key} ) {
-                    $Self->{SearchProfileObject}->SearchProfileAdd(
-                        Base      => 'TicketSearch',
-                        Name      => $Self->{Profile},
-                        Key       => $Key,
-                        Value     => $GetParam{$Key},
-                        UserLogin => $Self->{UserLogin},
-                    );
-                }
+                next if !$GetParam{$Key};
+                $Self->{SearchProfileObject}->SearchProfileAdd(
+                    Base      => 'TicketSearch',
+                    Name      => $Self->{Profile},
+                    Key       => $Key,
+                    Value     => $GetParam{$Key},
+                    UserLogin => $Self->{UserLogin},
+                );
             }
         }
 
@@ -378,7 +388,7 @@ sub Run {
                     = $GetParam{ArticleCreateTimeStartYear} . '-'
                     . $GetParam{ArticleCreateTimeStartMonth} . '-'
                     . $GetParam{ArticleCreateTimeStartDay}
-                    . ' 00:00:01';
+                    . ' 00:00:00';
             }
             if (
                 $GetParam{ArticleCreateTimeStopDay}
@@ -431,7 +441,7 @@ sub Run {
         # get create time settings
         if ( !$GetParam{TimeSearchType} ) {
 
-            # do noting with time stuff
+            # do nothing with time stuff
         }
         elsif ( $GetParam{TimeSearchType} eq 'TimeSlot' ) {
             for (qw(Month Day)) {
@@ -452,7 +462,7 @@ sub Run {
                     = $GetParam{TicketCreateTimeStartYear} . '-'
                     . $GetParam{TicketCreateTimeStartMonth} . '-'
                     . $GetParam{TicketCreateTimeStartDay}
-                    . ' 00:00:01';
+                    . ' 00:00:00';
             }
             if (
                 $GetParam{TicketCreateTimeStopDay}
@@ -505,7 +515,7 @@ sub Run {
         # get close time settings
         if ( !$GetParam{ChangeTimeSearchType} ) {
 
-            # do noting ont time stuff
+            # do nothing on time stuff
         }
         elsif ( $GetParam{ChangeTimeSearchType} eq 'TimeSlot' ) {
             for (qw(Month Day)) {
@@ -526,7 +536,7 @@ sub Run {
                     = $GetParam{TicketChangeTimeStartYear} . '-'
                     . $GetParam{TicketChangeTimeStartMonth} . '-'
                     . $GetParam{TicketChangeTimeStartDay}
-                    . ' 00:00:01';
+                    . ' 00:00:00';
             }
             if (
                 $GetParam{TicketChangeTimeStopDay}
@@ -579,7 +589,7 @@ sub Run {
         # get close time settings
         if ( !$GetParam{CloseTimeSearchType} ) {
 
-            # do noting ont time stuff
+            # do nothing on time stuff
         }
         elsif ( $GetParam{CloseTimeSearchType} eq 'TimeSlot' ) {
             for (qw(Month Day)) {
@@ -600,7 +610,7 @@ sub Run {
                     = $GetParam{TicketCloseTimeStartYear} . '-'
                     . $GetParam{TicketCloseTimeStartMonth} . '-'
                     . $GetParam{TicketCloseTimeStartDay}
-                    . ' 00:00:01';
+                    . ' 00:00:00';
             }
             if (
                 $GetParam{TicketCloseTimeStopDay}
@@ -672,7 +682,7 @@ sub Run {
                         = $GetParam{ 'TicketFreeTime' . $_ . 'StartYear' } . '-'
                         . $GetParam{ 'TicketFreeTime' . $_ . 'StartMonth' } . '-'
                         . $GetParam{ 'TicketFreeTime' . $_ . 'StartDay' }
-                        . ' 00:00:01';
+                        . ' 00:00:00';
                 }
                 if (
                     $GetParam{ 'TicketFreeTime' . $_ . 'StopDay' }
@@ -788,10 +798,17 @@ sub Run {
                 push @CSVData, \@Data;
             }
 
+            # get Separator from language file
+            my $UserCSVSeparator = $Self->{LayoutObject}->{LanguageObject}->{Separator};
+
+            if ( $Self->{ConfigObject}->Get('PreferencesGroups')->{CSVSeparator}->{Active} ) {
+                my %UserData = $Self->{UserObject}->GetUserData( UserID => $Self->{UserID} );
+                $UserCSVSeparator = $UserData{UserCSVSeparator};
+            }
             my $CSV = $Self->{CSVObject}->Array2CSV(
                 Head      => \@CSVHead,
                 Data      => \@CSVData,
-                Separator => $Self->{UserCSVSeparator},
+                Separator => $UserCSVSeparator,
             );
 
             # return csv to download
@@ -811,6 +828,9 @@ sub Run {
         }
         elsif ( $GetParam{ResultForm} eq 'Print' ) {
 
+            use Kernel::System::PDF;
+            $Self->{PDFObject} = Kernel::System::PDF->new( %{$Self} );
+
             my @PDFData;
             for (@ViewableTicketIDs) {
 
@@ -849,8 +869,6 @@ sub Run {
                 $UserInfo{CustomerName} = '(' . $UserInfo{CustomerName} . ')'
                     if ( $UserInfo{CustomerName} );
 
-                use Kernel::System::PDF;
-                $Self->{PDFObject} = Kernel::System::PDF->new( %{$Self} );
                 if ( $Self->{PDFObject} ) {
                     my %Info = ( %Data, %UserInfo );
                     my $Created = $Self->{LayoutObject}->Output(
@@ -909,45 +927,50 @@ sub Run {
                     $MaxPages = 100;
                 }
 
-                # create the header
                 my $CellData;
-                $CellData->[0]->[0]->{Content} = $Self->{ConfigObject}->Get('Ticket::Hook');
-                $CellData->[0]->[0]->{Font}    = 'ProportionalBold';
-                $CellData->[0]->[1]->{Content}
-                    = $Self->{LayoutObject}->{LanguageObject}->Get('Created');
-                $CellData->[0]->[1]->{Font} = 'ProportionalBold';
-                $CellData->[0]->[2]->{Content}
-                    = $Self->{LayoutObject}->{LanguageObject}->Get('From');
-                $CellData->[0]->[2]->{Font} = 'ProportionalBold';
-                $CellData->[0]->[3]->{Content}
-                    = $Self->{LayoutObject}->{LanguageObject}->Get('Subject');
-                $CellData->[0]->[3]->{Font} = 'ProportionalBold';
-                $CellData->[0]->[4]->{Content}
-                    = $Self->{LayoutObject}->{LanguageObject}->Get('State');
-                $CellData->[0]->[4]->{Font} = 'ProportionalBold';
-                $CellData->[0]->[5]->{Content}
-                    = $Self->{LayoutObject}->{LanguageObject}->Get('Queue');
-                $CellData->[0]->[5]->{Font} = 'ProportionalBold';
-                $CellData->[0]->[6]->{Content}
-                    = $Self->{LayoutObject}->{LanguageObject}->Get('Owner');
-                $CellData->[0]->[6]->{Font} = 'ProportionalBold';
-                $CellData->[0]->[7]->{Content}
-                    = $Self->{LayoutObject}->{LanguageObject}->Get('CustomerID');
-                $CellData->[0]->[7]->{Font} = 'ProportionalBold';
 
-                # create the content array
-                my $CounterRow = 1;
-                for my $Row (@PDFData) {
-                    my $CounterColumn = 0;
-                    for my $Content ( @{$Row} ) {
-                        $CellData->[$CounterRow]->[$CounterColumn]->{Content} = $Content;
-                        $CounterColumn++;
+                # verify if there are tickets to show
+                if (@PDFData) {
+
+                    # create the header
+                    $CellData->[0]->[0]->{Content} = $Self->{ConfigObject}->Get('Ticket::Hook');
+                    $CellData->[0]->[0]->{Font}    = 'ProportionalBold';
+                    $CellData->[0]->[1]->{Content}
+                        = $Self->{LayoutObject}->{LanguageObject}->Get('Created');
+                    $CellData->[0]->[1]->{Font} = 'ProportionalBold';
+                    $CellData->[0]->[2]->{Content}
+                        = $Self->{LayoutObject}->{LanguageObject}->Get('From');
+                    $CellData->[0]->[2]->{Font} = 'ProportionalBold';
+                    $CellData->[0]->[3]->{Content}
+                        = $Self->{LayoutObject}->{LanguageObject}->Get('Subject');
+                    $CellData->[0]->[3]->{Font} = 'ProportionalBold';
+                    $CellData->[0]->[4]->{Content}
+                        = $Self->{LayoutObject}->{LanguageObject}->Get('State');
+                    $CellData->[0]->[4]->{Font} = 'ProportionalBold';
+                    $CellData->[0]->[5]->{Content}
+                        = $Self->{LayoutObject}->{LanguageObject}->Get('Queue');
+                    $CellData->[0]->[5]->{Font} = 'ProportionalBold';
+                    $CellData->[0]->[6]->{Content}
+                        = $Self->{LayoutObject}->{LanguageObject}->Get('Owner');
+                    $CellData->[0]->[6]->{Font} = 'ProportionalBold';
+                    $CellData->[0]->[7]->{Content}
+                        = $Self->{LayoutObject}->{LanguageObject}->Get('CustomerID');
+                    $CellData->[0]->[7]->{Font} = 'ProportionalBold';
+
+                    # create the content array
+                    my $CounterRow = 1;
+                    for my $Row (@PDFData) {
+                        my $CounterColumn = 0;
+                        for my $Content ( @{$Row} ) {
+                            $CellData->[$CounterRow]->[$CounterColumn]->{Content} = $Content;
+                            $CounterColumn++;
+                        }
+                        $CounterRow++;
                     }
-                    $CounterRow++;
                 }
 
-                # output 'No ticket data found', if no content was given
-                if ( !$CellData->[0]->[0] ) {
+                # otherwise, show 'No ticket data found' message
+                else {
                     $CellData->[0]->[0]->{Content}
                         = $Self->{LayoutObject}->{LanguageObject}->Get('No ticket data found.');
                 }
@@ -1135,6 +1158,11 @@ sub Run {
             UserLogin => $Self->{UserLogin},
         );
 
+        # convert attributes
+        if ( $GetParam{ShownAttributes} && ref $GetParam{ShownAttributes} eq 'ARRAY' ) {
+            $GetParam{ShownAttributes} = join ';', @{ $GetParam{ShownAttributes} };
+        }
+
         # if no profile is used, set default params of default attributes
         if ( !$Profile ) {
             if ( $Self->{Config}->{Defaults} ) {
@@ -1410,12 +1438,12 @@ sub Run {
             SelectedID => $GetParam{CreatedUserIDs},
         );
         if ( $Self->{ConfigObject}->Get('Ticket::Watcher') ) {
-            $Param{WatchdUserStrg} = $Self->{LayoutObject}->BuildSelection(
+            $Param{WatchUserStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data       => \%ShownUsers,
-                Name       => 'WatchdUserIDs',
+                Name       => 'WatchUserIDs',
                 Multiple   => 1,
                 Size       => 5,
-                SelectedID => $GetParam{WatchdUserIDs},
+                SelectedID => $GetParam{WatchUserIDs},
             );
         }
         if ( $Self->{ConfigObject}->Get('Ticket::Responsible') ) {
@@ -1475,9 +1503,9 @@ sub Run {
 
             $Param{SearchInArchiveStrg} = $Self->{LayoutObject}->BuildSelection(
                 Data => {
-                    ArchivedTickets    => 'Search in archived tickets only',
-                    NotArchivedTickets => 'Search in not archived tickets only',
-                    AllTickets         => 'Search in all tickets',
+                    ArchivedTickets    => 'Archived tickets',
+                    NotArchivedTickets => 'Unarchived tickets',
+                    AllTickets         => 'All tickets',
                 },
                 Name => 'SearchInArchive',
                 SelectedID => $GetParam{SearchInArchive} || 'NotArchivedTickets',
@@ -1520,20 +1548,20 @@ sub Run {
             Type   => 'ro',
         );
         $Param{QueuesStrg} = $Self->{LayoutObject}->AgentQueueListOption(
-            Data           => \%AllQueues,
-            Size           => 5,
-            Multiple       => 1,
-            Name           => 'QueueIDs',
-            SelectedID     => $GetParam{QueueIDs},
-            OnChangeSubmit => 0,
+            Data               => \%AllQueues,
+            Size               => 5,
+            Multiple           => 1,
+            Name               => 'QueueIDs',
+            SelectedIDRefArray => $GetParam{QueueIDs},
+            OnChangeSubmit     => 0,
         );
         $Param{CreatedQueuesStrg} = $Self->{LayoutObject}->AgentQueueListOption(
-            Data           => \%AllQueues,
-            Size           => 5,
-            Multiple       => 1,
-            Name           => 'CreatedQueueIDs',
-            SelectedID     => $GetParam{CreatedQueueIDs},
-            OnChangeSubmit => 0,
+            Data               => \%AllQueues,
+            Size               => 5,
+            Multiple           => 1,
+            Name               => 'CreatedQueueIDs',
+            SelectedIDRefArray => $GetParam{CreatedQueueIDs},
+            OnChangeSubmit     => 0,
         );
         $Param{PrioritiesStrg} = $Self->{LayoutObject}->BuildSelection(
             Data => {
@@ -1961,9 +1989,11 @@ sub Run {
             Prefix => 'TicketCloseTimeStop',
             Format => 'DateInputFormat',
         );
+        my %GetParamBackup = %GetParam;
         for my $Key (qw(TicketClose TicketChange TicketCreate ArticleCreate)) {
             for my $SubKey (qw(TimeStart TimeStop TimePoint TimePointStart TimePointFormat)) {
                 delete $GetParam{ $Key . $SubKey };
+                delete $GetParamBackup{ $Key . $SubKey };
             }
         }
 
@@ -2002,47 +2032,50 @@ sub Run {
             Data => { %Param, %GetParam, %TicketFreeTextHTML, EmptySearch => $EmptySearch },
         );
 
-        if ( $Self->{Profile} ne '' && $Self->{Profile} ne 'last-search' ) {
-            $Self->{LayoutObject}->Block(
-                Name => 'SearchAJAXStoreInTemplate',
-                Data => { %Param, %GetParam, %TicketFreeTextHTML },
-            );
+        # comapt. map for attributes
+        my %Map = (
+            TimeSearchType        => 'TicketCreate',
+            ChangeTimeSearchType  => 'TicketChange',
+            CloseTimeSearchType   => 'TicketClose',
+            ArticleTimeSearchType => 'ArticleCreate',
+        );
+        for my $Key ( keys %Map ) {
+            next if !$GetParamBackup{$Key};
+            if ( $GetParamBackup{$Key} eq 'TimePoint' ) {
+                $GetParamBackup{ $Map{$Key} . 'TimePoint' } = 1;
+            }
+            elsif ( $GetParamBackup{$Key} eq 'TimeSlot' ) {
+                $GetParamBackup{ $Map{$Key} . 'TimeSlot' } = 1;
+            }
         }
 
         # show attributes
+        my @ShownAttributes;
+        if ( $GetParamBackup{ShownAttributes} ) {
+            @ShownAttributes = split /;/, $GetParamBackup{ShownAttributes};
+        }
         my %AlreadyShown;
         for my $Item (@Attributes) {
             my $Key = $Item->{Key};
             next if !$Key;
-            next if !defined $GetParam{$Key};
-            next if $GetParam{$Key} eq '';
 
-            # show time attributes
-            for my $Type (qw(Ticket Article)) {
-                for my $Item (qw(Change Create Close)) {
-                    next if $Type eq 'Article' && $Item =~ /^(Change|Close)$/;
-                    for my $ItemSubSub (qw(Point Slot)) {
-
-                        # compat.
-                        my $ItemSub;
-                        if ( $Item eq 'Create' && $Type eq 'Ticket' ) {
-                            $ItemSub = 'TimeSearchType::Time' . $ItemSubSub;
-                        }
-                        else {
-                            if ( $Type eq 'Ticket' ) {
-                                $ItemSub = $Item . 'TimeSearchType::Time' . $ItemSubSub;
-                            }
-                            else {
-                                $ItemSub = $Type . 'TimeSearchType::Time' . $ItemSubSub;
-                            }
-                        }
-                        if ( $Key eq $ItemSub && $GetParam{$ItemSub} && $GetParam{$ItemSub} eq 1 ) {
-                            $Key = $Type . $Item . 'Time' . $ItemSubSub;
-                        }
+            # check if shown
+            if (@ShownAttributes) {
+                my $Show = 0;
+                for my $ShownAttribute (@ShownAttributes) {
+                    if ( 'Label' . $Key eq $ShownAttribute ) {
+                        $Show = 1;
+                        last;
                     }
                 }
+                next if !$Show;
+            }
+            else {
+                next if !defined $GetParamBackup{$Key};
+                next if $GetParamBackup{$Key} eq '';
             }
 
+            # show attribute
             next if $AlreadyShown{$Key};
             $AlreadyShown{$Key} = 1;
             $Self->{LayoutObject}->Block(
