@@ -2,7 +2,7 @@
 # Kernel/Output/HTML/ArticleComposeSign.pm
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: ArticleComposeSign.pm,v 1.23.2.1 2012/05/24 23:19:58 cr Exp $
+# $Id: ArticleComposeSign.pm,v 1.21.2.1 2012/05/24 23:20:05 cr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -19,7 +19,7 @@ use Kernel::System::Crypt;
 use Kernel::System::Queue;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.23.2.1 $) [1];
+$VERSION = qw($Revision: 1.21.2.1 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -131,8 +131,12 @@ sub Data {
                 Search => $SearchAddress[0]->address(),
             );
             for my $DataRef (@PrivateKeys) {
-                $KeyList{"SMIME::Detached::$DataRef->{Filename}"}
-                    = "SMIME-Detached: $DataRef->{Filename} [$DataRef->{EndDate}] $DataRef->{Email}";
+                my $EndDate = '';
+                if ( $DataRef->{EndDate} ) {
+                    $EndDate = "[$DataRef->{EndDate}]";
+                }
+                $KeyList{"SMIME::Detached::$DataRef->{Hash}"}
+                    = "SMIME-Detached: $DataRef->{Hash} $EndDate $DataRef->{Email}";
             }
         }
 
