@@ -2,7 +2,7 @@
 # Kernel/System/Web/InterfaceCustomer.pm - the customer interface file (incl. auth)
 # Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
 # --
-# $Id: InterfaceCustomer.pm,v 1.56.2.1 2011/02/09 23:40:08 en Exp $
+# $Id: InterfaceCustomer.pm,v 1.56.2.7 2011/11/21 10:29:00 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @INC);
-$VERSION = qw($Revision: 1.56.2.1 $) [1];
+$VERSION = qw($Revision: 1.56.2.7 $) [1];
 
 # all framework needed modules
 use Kernel::Config;
@@ -332,12 +332,21 @@ sub Run {
         if ( !$Self->{ConfigObject}->Get('SessionUseCookieAfterBrowserClose') ) {
             $Expires = '';
         }
+
+        my $SecureAttribute;
+        if ( $Self->{ConfigObject}->Get('HttpType') eq 'https' ) {
+
+            # Restrict Cookie to HTTPS if it is used.
+            $SecureAttribute = 1;
+        }
+
         $LayoutObject = Kernel::Output::HTML::Layout->new(
             SetCookies => {
                 SessionIDCookie => $Self->{ParamObject}->SetCookie(
                     Key     => $Param{SessionName},
                     Value   => $NewSessionID,
                     Expires => $Expires,
+                    Secure  => scalar $SecureAttribute,
                 ),
             },
             SessionID   => $NewSessionID,
@@ -545,7 +554,20 @@ sub Run {
         $UserData{NewPW} = $Self->{UserObject}->GenerateRandomPassword();
 
         # update new password
-        $Self->{UserObject}->SetPassword( UserLogin => $User, PW => $UserData{NewPW} );
+        my $Success
+            = $Self->{UserObject}->SetPassword( UserLogin => $User, PW => $UserData{NewPW} );
+
+        if ( !$Success ) {
+            $LayoutObject->Print(
+                Output => \$LayoutObject->CustomerLogin(
+                    Title => 'Login',
+                    Message =>
+                        "Reset password unsuccessful. Please contact your administrator",
+                    User => $User,
+                ),
+            );
+            return;
+        }
 
         # send notify email
         my $Body = $Self->{ConfigObject}->Get('CustomerPanelBodyLostPassword')
@@ -1042,6 +1064,6 @@ did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =head1 VERSION
 
-$Revision: 1.56.2.1 $ $Date: 2011/02/09 23:40:08 $
+$Revision: 1.56.2.7 $ $Date: 2011/11/21 10:29:00 $
 
 =cut
